# Medical Vision-Language Processing
Algorithms and tools for Vision-Language Processing with Deep Learning.

# Setup environment

```bash
conda create --name medvlp python=3.9
conda activate medvlp
cd ~/repos/medvlp
pip install -e .
```
